@@ -94,14 +94,14 @@ void NewTokensFetchJob::start()
 
 void NewTokensFetchJob::dispatchRequest(QNetworkAccessManager* accessManager, const QNetworkRequest& request, const QByteArray& data, const QString& contentType)
 {
-    Q_UNUSED(contentType);
+    Q_UNUSED(contentType)
 
     accessManager->post(request, data);
 }
 
 void NewTokensFetchJob::handleReply(const QNetworkReply *reply, const QByteArray& rawData)
 {
-    Q_UNUSED(reply);
+    Q_UNUSED(reply)
 
     QJsonDocument document = QJsonDocument::fromJson(rawData);
     if (document.isNull()) {
